package fr.shortcircuit.pattern.chain.node;

import org.apache.commons.collections.Predicate;

import fr.shortcircuit.pattern.chain.node.definition.AbstractProcessorNode;
import fr.shortcircuit.pattern.chain.node.definition.IChainNode;
import fr.shortcircuit.pattern.chain.request.definition.IRequest;

/** 
 * @author Dimitri Dean DARSEYNE (D3), 
 * Published by Short-Circuit under Creative Commons (CC) Licensing: 
 * Authorship/Paternity, NO Commercial Use, NO Derivative
 * Please check for more informations:
 * http://creativecommons.org/licenses/by-nc-nd/2.0/
 *
 * Auteur Dimitri Dean DARSEYNE (D3),
 * Publié par Short-Circuit sous license Creative Commons (CC):
 * Paternité, PAS d'Utilisation Commerciale, pas de Dérivés/Modifications
 * Pour plus d'informations, se rendre sur:
 * http://creativecommons.org/licenses/by-nc-nd/2.0/fr/ 
 * 
 * @since Short-Circuit 1999
 */

/**
 * A Processing class, representing a chain node, 
 * specialized in IRequest targeted object Predicate evaluation.
 * 
 * Une classe de traitement, représentant un noeud de la chaîne,
 * spécialisée dans l'évaluation de Prédicat sur des objets IRequest cibles.  
 */
public class PredicateProcessorNode extends AbstractProcessorNode 
{
	/** 
	 * The local Predicate qualifying this node.
	 *  
	 * Le Prédicat local, qualifiant ce noeud. 
	 */
	private Predicate 	predicateRule;
	
	
	public PredicateProcessorNode(Predicate predicateRule) 
	{
		this.predicateRule = predicateRule;
	}
	
	/**
	 * Process the given IRequest with the Predicate,
	 *  
	 * if:	 The evaluated rule is verified/true, 
	 * then: The IRequest is callbacked decorated with the present Predicate (added to its List), 
	 *       and the node tries to forward the IRequest to its successor (if existing)
	 * else: The chain ends with this current node.
	 * 
	 * 
	 * Traite l'IRequest donnée avec le Prédicat,
	 * 
	 * si: 		La règle évaluée est vérifiée/vraie,
	 * alors: 	L'IRequest est décorée par rappel avec le Predicat actuel (ajouté à sa liste), 
	 * 			et le noeud essaye de faire suivre la IRequest à son successeur (s'il existe)
	 * sinon:	La chaîne se termine avec ce noeud courant.
	 */
	@Override
	public void process(IRequest request) 
	{
		if (predicateRule.evaluate(request))
		{
			IChainNode nextNode = getNextNode();

			request.decorate(predicateRule);
			
			if (nextNode != null)
				nextNode.process(request);
		}
	}
}
