package fr.shortcircuit.pattern.chain.node.definition;

/** 
 * @author Dimitri Dean DARSEYNE (D3), 
 * Published by Short-Circuit under Creative Commons (CC) Licensing: 
 * Authorship/Paternity, NO Commercial Use, NO Derivative
 * Please check for more informations:
 * http://creativecommons.org/licenses/by-nc-nd/2.0/
 *
 * Auteur Dimitri Dean DARSEYNE (D3),
 * Publié par Short-Circuit sous license Creative Commons (CC):
 * Paternité, PAS d'Utilisation Commerciale, pas de Dérivés/Modifications
 * Pour plus d'informations, se rendre sur:
 * http://creativecommons.org/licenses/by-nc-nd/2.0/fr/ 
 * 
 * @since Short-Circuit 1999
 */

/**
 * Top Level abstract class, providing:
 * - La déclaration dans sa signature de classe de l’implémentation de IChainNode
 * - Simple/trivial constructor for subclasses convenience
 * - IChainNode "nextNode" getter/setter implementation, through dedicated private property. 
 *
 * Remark: IChainNode remaining requested "process" method implementation forwarded to concrete subclasses.
 *
 * 
 * Classe d'abstraction de haut niveau, fournissant:
 * - Un constructeur simple/trivial pour la commodité des sous-classes
 * - L'implémentation des getters/setters de "nextNode" (associé à l’interface IChainNode), à travers une propriété privée dédiée.
 *  
 * Remarque: L'implémentation de la méthode "process", requise et restante depuis la déclaration d'IChainNode, est renvoyée aux sous-classes concrètes. 
 */
public abstract class AbstractProcessorNode implements IChainNode
{
    private IChainNode nextNode;
    
    
    public AbstractProcessorNode() {}   
   
    @Override
    public IChainNode getNextNode()				{return nextNode;} 
    @Override
    public void setNextNode(IChainNode node)	{this.nextNode = node;}
}
