package fr.shortcircuit.pattern.chain.request;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.collections.Predicate;

import fr.shortcircuit.pattern.chain.request.definition.IRequest;

/** 
 * @author Dimitri Dean DARSEYNE (D3), 
 * Published by Short-Circuit under Creative Commons (CC) Licensing: 
 * Authorship/Paternity, NO Commercial Use, NO Derivative
 * Please check for more informations:
 * http://creativecommons.org/licenses/by-nc-nd/2.0/
 *
 * Auteur Dimitri Dean DARSEYNE (D3),
 * Publié par Short-Circuit sous license Creative Commons (CC):
 * Paternité, PAS d'Utilisation Commerciale, pas de Dérivés/Modifications
 * Pour plus d'informations, se rendre sur:
 * http://creativecommons.org/licenses/by-nc-nd/2.0/fr/ 
 * 
 * @since Short-Circuit 1999
 */

/**
 * A simple "token" request class, providing a minimum of functionnal properties.
 * 
 * Une simple classe "jeton" de requête, fournissant un minimum de propriétés fonctionnelles.
 */
public class Request implements IRequest
{
	/**
	 * A Rule/Predicate list, matched by the current object, 
	 * and fed under Design Pattern "Decorator". 
	 * 
	 * Une liste de règle/prédicat, que l'objet courant vérifie, 
	 * et alimentée selon le Design Pattern "Decorator"  
	 */
	private List<Predicate> matchingPredicates = new ArrayList<Predicate>();
	
	/** 
	 * Object title 
	 * 
	 * Titre de l'objet 
	 */
	private String			title;
	
	/** 
	 * An simple value, "Object" typed   
	 * 
	 * Une simple valeur, typée "Object" 
	 */
	private Object 			value;
	
	
    public Request(String title, Object value) 	
    {	
    	this.title = title; 
    	this.value = value;
    }
    
    /** 
     * Callbacked values injection
     * 
     * Injection de valeurs par rappel
     */
    public void decorate(Predicate matchingRulepredicate)
    {
    	matchingPredicates.add(matchingRulepredicate);
    }

    /**
     * A local properties composed java.lang.Object.toString overriding
     *  
     * Une redéfinition de java.lang.Object.toString composée de propriétés locales 
     */
    @Override
    public String toString()						{return title + " (value=" + ((value == null)? "null" : value.toString()) + ")";}
    
    /** 
     * Read-only properties (no setters/write access)
     * 
     * propriétés en lecture seule (pas de setter/d'accès en écriture) 
     */
	public Object getValue() 						{return value;}
	public List<Predicate> getMatchingPredicates() 	{return matchingPredicates;}
	public String getTitle() 						{return title;}
}
